@@ -181,15 +181,15 @@ def collect_logs(scene: Scene, client: aws.S3):
 
 def run(scene_key):
     assert os.environ['ADSK_3DSMAX_x64_2018'], "ADSK_3DSMAX_x64_2018 must be defined"
-    assert user_data['AWS_ACCESS_KEY_ID'], "AWS_ACCESS_KEY_ID must be defined"
-    assert user_data['AWS_SECRET_ACCESS_KEY'], "AWS_SECRET_ACCESS_KEY must be defined"
-    assert user_data['AWS_ENDPOINT'], "AWS_ENDPOINT must be defined"
-    assert user_data['AWS_BUCKET'], "AWS_BUCKET must be defined"
+    assert user_data['aws_access_key_id'], "aws_access_key_id must be defined"
+    assert user_data['aws_secret_access_key'], "aws_secret_access_key must be defined"
+    assert user_data['aws_endpoint'], "aws_endpoint must be defined"
+    assert user_data['aws_bucket'], "aws_bucket must be defined"
     s3 = aws.S3(
-        user_data['AWS_BUCKET'],
-        aws_access_key_id=user_data['AWS_ACCESS_KEY_ID'],
-        aws_secret_access_key=user_data['AWS_SECRET_ACCESS_KEY'],
-        endpoint_url=user_data['AWS_ENDPOINT'],
+        user_data['aws_bucket'],
+        aws_access_key_id=user_data['aws_access_key_id'],
+        aws_secret_access_key=user_data['aws_secret_access_key'],
+        endpoint_url=user_data['aws_endpoint'],
     )
     scene = Scene(scene_key)
     # configure current logger for the specific scene
